==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/sk.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Štítky",
    "Update" : "Aktualizovať",
    "Create" : "Vytvoriť",
    "Select tag…" : "Vyber štítok...",
    "System tag %1$s added by the system" : "Systémový štítok %1$s bol pridaný systémom",
    "Added system tag {systemtag}" : "Pridaný systémový štítok {systemtag}",
    "Added system tag %1$s" : "Pridaný systémový štítok %1$s",
    "%1$s added system tag %2$s" : "%1$s pridal(a) systémový štítok %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridal(a) systémový štítok {systemtag}",
    "System tag %1$s removed by the system" : "Systémový štítok %1$s bol odstránený systémom",
    "Removed system tag {systemtag}" : "Odstránený systémový štítok {systemtag}",
    "Removed system tag %1$s" : "Odstránený systémový štítok %1$s",
    "%1$s removed system tag %2$s" : "%1$s odstránil(a) systémový štítok %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You created system tag %1$s" : "Vytvorili ste systémový štítok %1$s",
    "You created system tag {systemtag}" : "Vytvorili ste systémový štítok {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvoril systémový štítok %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvoril(a) systémový štítok {systemtag}",
    "You deleted system tag %1$s" : "Zmazali ste systémový štítok %1$s",
    "You deleted system tag {systemtag}" : "Odstránili ste systémový štítok {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s zmazal(a) systémový štítok %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali ste systémový štítok %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali ste systémový štítok {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítok %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítok {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systémový štítok %2$s bol sytémom pridaný do %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Súboru {file} bol systémom pridaný systémový štítok {systemtag}",
    "You added system tag %2$s to %1$s" : "Pridali ste systémový štítok %2$s na %1$s",
    "You added system tag {systemtag} to {file}" : "K {file} ste pridali systémový štítok {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s k %2$s pridal(a) systémový štítok %3$s",
    "{actor} added system tag {systemtag} to {file}" : " {actor} k {file} pridal(a) systémový štítok {systemtag}",
    "You removed system tag %2$s from %1$s" : "Z %2$s ste odstránili systémový štítok %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} ste odstránili systémový štítok {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstránil(a) systémový štítok %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstránil(a) systémový štítok {systemtag} z {file}",
    "%s (restricted)" : "%s (obmedzené)",
    "%s (invisible)" : "%s (neviditeľné)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> súboru boli upravené",
    "Collaborative tags" : "Značky pre spoluprácu",
    "Tagged files" : "Súbory so štítkom",
    "Select tags to filter by" : "Vybrať štítky pre filter",
    "No tags found" : "Štítky sa nenašli",
    "Please select tags to filter by" : "Vyberte štítky pre filtrovanie",
    "No files found for the selected tags" : "Neboli nájdené žiadne súbory označené vybranými štítkami",
    "Select tag …" : "Vybrať štítok ...",
    "Create a new tag" : "Vytvoriť nový štítok",
    "Name" : "Názov",
    "Public" : "Verejné",
    "Restricted" : "Obmedzené",
    "Invisible" : "Neviditeľné",
    "Delete" : "Zmazať",
    "Reset" : "Vynulovať",
    "No files in here" : "Žiadne súbory",
    "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
    "Size" : "Veľkosť",
    "Modified" : "Upravené"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-21.0.0-9-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/sk.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Názov štítku je prázdny",
    "Update" : "Aktualizovať",
    "Create" : "Vytvoriť",
    "Select tag…" : "Vyber štítok...",
    "System tag %1$s added by the system" : "Systémový štítok %1$s bol pridaný systémom",
    "Added system tag {systemtag}" : "Pridaný systémový štítok {systemtag}",
    "Added system tag %1$s" : "Pridaný systémový štítok %1$s",
    "%1$s added system tag %2$s" : "%1$s pridal(a) systémový štítok %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridal(a) systémový štítok {systemtag}",
    "System tag %1$s removed by the system" : "Systémový štítok %1$s bol odstránený systémom",
    "Removed system tag {systemtag}" : "Odstránený systémový štítok {systemtag}",
    "Removed system tag %1$s" : "Odstránený systémový štítok %1$s",
    "%1$s removed system tag %2$s" : "%1$s odstránil(a) systémový štítok %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You created system tag %1$s" : "Vytvorili ste systémový štítok %1$s",
    "You created system tag {systemtag}" : "Vytvorili ste systémový štítok {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvoril systémový štítok %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvoril(a) systémový štítok {systemtag}",
    "You deleted system tag %1$s" : "Zmazali ste systémový štítok %1$s",
    "You deleted system tag {systemtag}" : "Odstránili ste systémový štítok {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s zmazal(a) systémový štítok %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali ste systémový štítok %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali ste systémový štítok {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítok %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítok {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systémový štítok %2$s bol sytémom pridaný do %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Súboru {file} bol systémom pridaný systémový štítok {systemtag}",
    "You added system tag %2$s to %1$s" : "Pridali ste systémový štítok %2$s na %1$s",
    "You added system tag {systemtag} to {file}" : "K {file} ste pridali systémový štítok {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s k %2$s pridal(a) systémový štítok %3$s",
    "{actor} added system tag {systemtag} to {file}" : " {actor} k {file} pridal(a) systémový štítok {systemtag}",
    "System tag %2$s was removed from %1$s by the system" : "Systémový štítok %2$s bol z %1$s odstránený systémom",
    "System tag {systemtag} was removed from {file} by the system" : "Systémový štítok {systemtag} bol z {file} odstránený systémom",
    "You removed system tag %2$s from %1$s" : "Z %2$s ste odstránili systémový štítok %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} ste odstránili systémový štítok {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstránil(a) systémový štítok %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstránil(a) systémový štítok {systemtag} z {file}",
    "%s (restricted)" : "%s (obmedzené)",
    "%s (invisible)" : "%s (neviditeľné)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> súboru boli upravené",
    "Tags" : "Štítky",
    "Collaborative tags" : "Značky pre spoluprácu",
    "Collaborative tagging functionality which shares tags among users." : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi používateľmi.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi používateľmi. Skvelé pre tímy.\n\t (Ak ste poskytovateľom inštalácie pre viacero subjektov, odporúča sa túto aplikáciu deaktivovať, pretože štítky sú zdieľané.)",
    "Tagged files" : "Súbory so štítkom",
    "Select tags to filter by" : "Vybrať štítky pre filter",
    "No tags found" : "Štítky sa nenašli",
    "Please select tags to filter by" : "Vyberte štítky pre filtrovanie",
    "No files found for the selected tags" : "Neboli nájdené žiadne súbory označené vybranými štítkami",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pre spoluprácu sú k dispozícii pre všetkých používateľov. Obmedzené značky sú viditeľné pre používateľov, ale nedajú sa priradiť. Neviditeľné značky sú určené na interné použitie, pretože používatelia ich nemôžu vidieť ani priradiť.",
    "Select tag …" : "Vybrať štítok ...",
    "Create a new tag" : "Vytvoriť nový štítok",
    "Name" : "Názov",
    "Public" : "Verejné",
    "Restricted" : "Obmedzené",
    "Invisible" : "Neviditeľné",
    "Delete" : "Zmazať",
    "Reset" : "Vynulovať",
    "No files in here" : "Žiadne súbory",
    "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
    "Size" : "Veľkosť",
    "Modified" : "Upravené"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
